/***************************************************************************
                          sprite.cpp  -  description
                             -------------------
    begin                : Sat Feb 9 2002
    copyright            : (C) 2002 by funthing (Matthias Zisler)
    email                : matthias@zislers.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "sprite.h"
#include "timer.h"

Sprite::Sprite(CL_Surface* _sur, float _speed)
{
	sur=_sur;
	speed=_speed;
	spr=0;
	offset=0;
	spr_n=sur->get_num_frames();
	pause=false;
	timer=new Timer;
	loop=true;
	played=false;
}
Sprite::Sprite(CL_Surface* _sur, float _speed, int _offset, int _max)
{
	sur=_sur;
	speed=_speed;
	offset=_offset;
	spr=0+offset;
	spr_n=_max;
	pause=false;
	timer=new Timer;
	loop=true;
	played=false;
}
Sprite::Sprite(CL_Surface* _sur, float _speed, int _offset, int _max, int _start)
{
	sur=_sur;
	speed=_speed;
	offset=_offset;
	spr=_start;
	spr_n=_max;
	pause=false;
	timer=new Timer;
	loop=true;
	played=false;
}
Sprite::~Sprite()
{
}
void Sprite::set_new(int _offset, int _max)
{
	if(!(spr_n==_max && offset==_offset))
	{
	inv=false;
	spr_n=_max;
	offset=_offset;
	spr=0+offset;
	loop=true;
	played=false;
	timer->reset();
	}
}
void Sprite::set_new(float _speed, int _offset, int _max)
{
	if(!(spr_n==_max && offset==_offset))
	{
	inv=false;
	spr_n=_max;
	offset=_offset;
	speed=_speed;
	spr=0+offset;
	loop=true;
	played=false;
	timer->reset();
	}
}
void Sprite::set_new(bool i, float _speed, int _offset, int _max)
{
	if(!(spr_n==_max && offset==_offset))
	{
	inv=i;
	spr_n=_max;
	offset=_offset;
	speed=_speed;
	spr=spr_n-1;
	loop=true;
	played=false;
	timer->reset();
	}
}
void Sprite::play_once()
{
	played=false;
}
bool Sprite::is_played()
{
	if(!inv)
	{
		if(spr>=spr_n-1)
		return true;
	}
	else
	{
		if(spr==offset)
		return true;
	}

return false;
}
void Sprite::set_loop(bool o)
{
	loop=o;
}
void Sprite::set_speed(float _speed)
{
	speed=_speed;
}
void Sprite::set_inv(bool i)
{
	inv=i;
}
void Sprite::jump_to(int n)
{
	if(!n>spr_n)
	spr=n;
}
void Sprite::set_pause(bool p)
{
	pause=p;
}
void Sprite::put_screen(int x, int y)
{
	anim();

	if((spr<=sur->get_num_frames() || spr>=0) )
	sur->put_screen(x, y, spr);
//	else
//	cout<<"Debug: frame "<<spr<<" in sprite not available!"<<endl;
}
void Sprite::put_screen(int x, int y, float scale_x, float scale_y)
{
	anim();

	if(spr<=sur->get_num_frames() || spr>=0)
	sur->put_screen(x, y, scale_x, scale_y, spr);
//  else
//  cout<<"Debug: frame "<<spr<<" in sprite not available!"<<endl;
}
void Sprite::anim()
{
	if(pause==false && timer->time_elapsed()>=speed && !played)
	{
		timer->reset();

		if(inv!=true)
		{
			if(spr<spr_n-1)
			spr++;
			else
			{
				if(loop==false)
				played=true;

				spr=0+offset;
			}
		}
		else
		{
			if(spr>offset)
			spr--;
			else
			{
				if(loop==false)
				played=true;

				spr=spr_n-1;
			}
		}
	}
}
int Sprite::get_fnum()
{
	return spr;
}